@@ -1,7 +1,7 @@
 context("cloud_metrics")
 
 LASfile <- system.file("extdata", "example.laz", package = "rlas")
-las     <- readLAS(LASfile)
+las     <- example
 ctg     <- suppressMessages(readLAScatalog(c(LASfile, LASfile)))
 opt_progress(ctg) <- FALSE
 
@@ -33,3 +33,4 @@ test_that("cloud_metrics works with catalog_apply", {
   expect_is(x[[2]], "list")
 })
 
+
